/*****************************************************************************
 *									     *
 *     Copyright (c) 1986                  The Santa Cruz Operation, Inc.    *
 *									     *
 *     All rights reserved. No part of this program or publication may be    *
 *     reproduced, transmitted, transcribed, stored in a retrieval system,   *
 *     or translated into any language or computer language, in any form or  *
 *     by any means, electronic, mechanical, magnetic, optical, chemical,    *
 *     biological, or otherwise, without the prior written permission of:    *
 *									     *
 *	      The Santa Cruz Operation, Inc      (408) 425-7222	             *
 *	      500 Chestnut St, Santa Cruz, California 95060 USA              *
 *									     *
 *****************************************************************************/

/*
 *  hpcpro.h
 *
 *	Include file for the HP Color Pro plotter.  This file contains
 *	#defines that specify important numbers and character strings.
 */

#define	NUMCOLORS	8	/* number of pens */

/*
 * The HP Color Pro has the ability to scale to the user specified 
 * coordinate system.  This means that the driver need not be concerned
 * with scaling points as long as it first downloads the coordinate
 * system to the Color Pro.  The following four numbers define the
 * absolute plotter coordinates that will correspond to output
 * coordinates.  Numbers are chosen to produce a square offset into
 * the middle of the page.
 */
#define	IPXMIN		1650
#define	IPYMIN		279
#define	IPXMAX		8850
#define	IPYMAX		7479

/* Following two offsets are used in character alignment */
#define	MAG_HALF	0.5	/* percentage of character to offset */
#define	MAG_BASE	0.0

/* Increment used when simulating arcs */
#define	CIRCINC		M_PI/100

/* Maximum length of string */
#define	MAXSTR	100

/*
 * The following defines describe the strings output to the ColorPro
 * to perform various actions.
 */
#define	PEN_UP()		printf("PU;")
#define	REPLACE_PEN()		printf("SP0;")
#define	INIT_PLOT()		printf("IN;")
#define	SET_HARD_CLIP()		printf("IP%d,%d,%d,%d;",IPXMIN, IPYMIN, IPXMAX, IPYMAX)
#define	SET_SCALE_RANGE()	printf("SC0,%d,0,%d;",VIRTMAX,VIRTMAX)
#define	LINE_SOLID()		printf("LT;")
#define	LINE_STYLE(a)		printf("LT%d;",a)
#define	MOVE_TO(a)		printf("PA%d,%d;",PX(a),PY(a))
#define	LINE(a)			printf("PD%d,%d;",PX(a),PY(a))
#define	SETCOLOR(a)		printf("SP%d;",a)
#define	LABEL(a)		printf("LB%s\003",a)
#define	ROTATE_TEXT(a)		printf("DR%f,%f;",cos(a),sin(a))
#define	CHAR_POSITION(x,y)	printf("CP%f,%f;",x,y)
#define	SET_TEXT_SIZE(w, h)	printf("SR%f,%f;",w,h)
#define	SET_SYMBOL_CHAR(a)	printf("SM%c;",a)
#define	STOP_SYMBOLS()		printf("SM;")
#define	USE_XON_XOFF()		printf("\033.P1");
